/* File: geometry_non_linear_scale_test.h; Copyright and License: see below */

#ifndef GEOMETRY_NON_LINEAR_SCALE_TEST_H
#define GEOMETRY_NON_LINEAR_SCALE_TEST_H

/*!
 *  \file
 *  \brief UNITTEST for geometry_non_linear_scale
 */

#include "test_suite.h"

test_suite_t geometry_non_linear_scale_test_get_list(void);

#endif  /* GEOMETRY_NON_LINEAR_SCALE_TEST_H */


/*
 * Copyright 2016-2021 Andreas Warnke
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
